@@ -5,9 +5,9 @@
 
 --------------------------------------------------------------------------------
 gSOAP XML Web services tools
-Copyright (C) 2000-2017, Robert van Engelen, Genivia Inc. All Rights Reserved.
+Copyright (C) 2000-2021, Robert van Engelen, Genivia Inc. All Rights Reserved.
 This part of the software is released under one of the following licenses:
-GPL or Genivia's license for commercial use.
+GPL.
 --------------------------------------------------------------------------------
 GPL license.
 
@@ -44,8 +44,21 @@ A commercial use license is available from Genivia, Inc., contact@genivia.com
 #include "error2.h"
 
 #ifndef VERSION
-# define VERSION "2.8.60" /* Current version */
-# define GSOAP_VERSION 20860
+# define VERSION "2.8.117" /* Current version */
+# define GSOAP_VERSION 208117
+#endif
+
+#ifdef _WIN32
+# ifndef WIN32
+#  define WIN32
+# endif
+#endif
+
+/* for legacy purposes we use WIN32 macro, even when WIN64 is supported */
+#ifdef _WIN64
+# ifndef WIN32
+#  define WIN32
+# endif
 #endif
 
 #ifdef WIN32
@@ -124,63 +137,65 @@ typedef enum Bool {False, True} Bool;
 typedef int Token;
 
 typedef enum Type
-{       Tnone,
-        Tvoid,
-        Tchar,          /* primitive types from here*/
-        Twchar,
-        Tshort,
-        Tint,
-        Tlong,
-        Tllong,
-        Tfloat,
-        Tdouble,
-        Tldouble,
-        Tuchar,
-        Tushort,
-        Tuint,
-        Tulong,
-        Tullong,
-        Tsize,
-        Ttime,
-        Tenum,
-        Tenumsc,
-        Tclass,         /* compound types from here */
-        Tstruct,
-        Tunion,
-        Tpointer,       /* pointer T* */
-        Treference,     /* reference T& */
-        Trvalueref,     /* C+11 rvalue reference T&& */
-        Tarray,         /* fixed size array T[N] */
-        Ttemplate,      /* template class<T> */
-        Tfun
+{
+  Tnone,
+  Tvoid,
+  Tchar,          /* primitive types from here*/
+  Twchar,
+  Tshort,
+  Tint,
+  Tlong,
+  Tllong,
+  Tfloat,
+  Tdouble,
+  Tldouble,
+  Tuchar,
+  Tushort,
+  Tuint,
+  Tulong,
+  Tullong,
+  Tsize,
+  Ttime,
+  Tenum,
+  Tenumsc,
+  Tclass,         /* compound types from here */
+  Tstruct,
+  Tunion,
+  Tpointer,       /* pointer T* */
+  Treference,     /* reference T& */
+  Trvalueref,     /* C+11 rvalue reference T&& */
+  Tarray,         /* fixed size array T[N] */
+  Ttemplate,      /* template class<T> */
+  Tfun
 } Type;
 
 #define TYPES (Tfun+1)  /* number of type (operators) enumerated above */
 
 typedef enum Storage
-{       Snone           = 0,
-        Sauto           = 0x000001,
-        Sregister       = 0x000002,
-        Sstatic         = 0x000004,
-        Sextern         = 0x000008,
-        Stypedef        = 0x000010,
-        Svirtual        = 0x000020,
-        Sconst          = 0x000040,
-        Sconstobj       = 0x000080,
-        Sfinal          = 0x000100,
-        Soverride       = 0x000200,
-        Sconstptr       = 0x000400,
-        Sfriend         = 0x000800,
-        Sinline         = 0x001000,
-        Sabstract       = 0x002000,
-        SmustUnderstand = 0x004000,
-        Sreturn         = 0x008000,
-        Sattribute      = 0x010000,
-        Sspecial        = 0x020000,
-        Sexplicit       = 0x040000,
-        Sprivate        = 0x080000,
-        Sprotected      = 0x100000,
-        Smutable        = 0x200000
+{
+  Snone           = 0,
+  Sauto           = 0x000001,
+  Sregister       = 0x000002,
+  Sstatic         = 0x000004,
+  Sextern         = 0x000008,
+  Stypedef        = 0x000010,
+  Svirtual        = 0x000020,
+  Sconst          = 0x000040,
+  Sconstobj       = 0x000080,
+  Sfinal          = 0x000100,
+  Soverride       = 0x000200,
+  Sconstptr       = 0x000400,
+  Sfriend         = 0x000800,
+  Sinline         = 0x001000,
+  Sabstract       = 0x002000,
+  SmustUnderstand = 0x004000,
+  Sreturn         = 0x008000,
+  Sattribute      = 0x010000,
+  Sspecial        = 0x020000,
+  Sexplicit       = 0x040000,
+  Sprivate        = 0x080000,
+  Sprotected      = 0x100000,
+  Smutable        = 0x200000
 } Storage;
 
 typedef enum Level { INTERNAL, GLOBAL, PARAM, LOCAL } Level;
@@ -219,100 +234,123 @@ typedef enum Level { INTERNAL, GLOBAL, PARAM, LOCAL } Level;
 #define mkstring()      mkpointer(mkchar())
 
 typedef struct Symbol
-{       char            *name;
-        Token           token;
-        struct Symbol   *next;
+{
+  Token           token;
+  struct Symbol   *next;
+  struct Symbol   *left;
+  struct Symbol   *right;
+  char            name[1]; /* the actual string value flows into the allocated region id[0...] below this struct */
 } Symbol;
 
 Symbol  *install(const char*, Token), *lookup(const char*), *gensym(const char*), *gensymidx(const char*, int);
 
+typedef enum Visited { Unexplored, Cold, Hot } Visited;
+
 typedef struct Tnode
-{       Type            type;
-        void            *ref;
-        Symbol          *id;    /* struct/class/union/enum name */
-        Symbol          *base;  /* base class name */
-        Symbol          *sym;   /* typedef name */
-        Symbol          *restriction;   /* restriction via typedef base id */
-        Symbol          *synonym;       /* synonymous typedef base name for typedef base id */
-        Symbol          *extsym;        /* typedef sym of external type w/ custom serializer */
-        struct Entry    *response; /* funcs only: points to response struct */
-        int             width;
-        int             transient;
-        const char      *imported;
-        struct Tnode    *next;
-        Bool            visited;
-        Bool            recursive;      /* recursive data type */
-        Bool            generated;
-        Bool            wsdl;
-        int             num;
-        Bool            hasmin;
-        Bool            hasmax;
-        Bool            incmin;
-        Bool            incmax;
-        double          min;
-        double          max;
-        int             property;
-        const char      *pattern;
+{
+  Type            type;
+  void            *ref;
+  Symbol          *id;     /* struct/class/union/enum name */
+  Symbol          *baseid; /* base class name */
+  Symbol          *sym;    /* typedef name */
+  Symbol          *restriction;   /* restriction via typedef base id */
+  Symbol          *synonym;       /* synonymous typedef base name for typedef base id */
+  Symbol          *extsym;        /* typedef sym of external type w/ custom serializer */
+  struct Entry    *response; /* funcs only: points to response struct */
+  int             width;
+  int             transient;
+  const char      *imported;
+  struct Tnode    *next;
+  struct Tnode    *base;
+  Visited         visited;
+  Bool            recursive;      /* recursive data type */
+  Bool            generated;
+  Bool            wsdl;
+  int             num;
+  Bool            hasmin;
+  Bool            hasmax;
+  Bool            incmin;
+  Bool            incmax;
+  LONG64          imin;
+  LONG64          imax;
+  double          rmin;
+  double          rmax;
+  int             property;
+  const char      *pattern;
 } Tnode;
 
-typedef union Value {
-        LONG64          i;
-        double          r;
-        const char      *s;
+typedef union Value
+{
+  LONG64          i;
+  double          r;
+  const char      *s;
 } Value;
 
-typedef struct IDinfo {
-        Tnode           *typ;
-        Storage         sto;
-        Bool            hasval;         /* if true, identifier has a default value */
-        Bool            ptrval;         /* if true, identifier is a pointer to a default value */
-        Bool            fixed;          /* if true and hasval, identifier has a fixed value */
-        Value           val;            /* ... with this value */
-        int             offset;
-        LONG64          minOccurs;
-        LONG64          maxOccurs;
-        Bool            nillable;
+typedef struct IDinf
+{
+  Tnode           *typ;
+  Storage         sto;
+  Bool            hasval;         /* if true, identifier has a default value */
+  Bool            ptrval;         /* if true, identifier is a pointer to a default value */
+  Bool            fixed;          /* if true and hasval, identifier has a fixed value */
+  Value           val;            /* ... with this value */
+  int             offset;
+  LONG64          minOccurs;
+  LONG64          maxOccurs;
+  Bool            nillable;
 } IDinfo;
 
-typedef struct Entry {
-        Symbol          *sym;
-        const char      *tag;
-        IDinfo          info;
-        Level           level;
-        const char      *filename;
-        int             lineno;
-        struct Entry    *next;
+typedef struct Entry
+{
+  Symbol          *sym;
+  const char      *tag;
+  IDinfo          info;
+  Level           level;
+  const char      *filename;
+  int             lineno;
+  struct Entry    *next;
 } Entry;
 
-typedef struct Table {
-        Symbol          *sym;
-        Level           level;
-        Entry           *list;
-        struct Table    *prev;
+typedef struct Table
+{
+  Symbol          *sym;
+  Level           level;
+  Entry           *list;
+  struct Table    *prev;
 } Table;
 
-typedef struct FNinfo {
-        Tnode   *ret;
-        Table   *args;
+typedef struct FNinfo
+{
+  Tnode   *ret;
+  Table   *args;
 } FNinfo;
 
-typedef struct Node {
-        Tnode           *typ;
-        Storage         sto;
-        Bool            hasval;         /* if true, this node has a default value */
-        Bool            fixed;          /* if true and hasval, this node has a fixed value */
-        Value           val;            /* ... this is the value */
-        Bool            hasmin;
-        Bool            hasmax;
-        Bool            incmin;
-        Bool            incmax;
-        LONG64          minOccurs;
-        LONG64          maxOccurs;
-        double          min;
-        double          max;
-        Bool            nillable;
-        int             property;
-        const char      *pattern;
+typedef struct IR
+{
+  LONG64 i;
+  double r;
+} IR;
+
+typedef struct Node
+{
+  Tnode           *typ;
+  Storage         sto;
+  Bool            hasval;         /* if true, this node has a default value */
+  Bool            fixed;          /* if true and hasval, this node has a fixed value */
+  Value           val;            /* ... this is the value */
+  Bool            hasmin;
+  Bool            hasmax;
+  Bool            incmin;
+  Bool            incmax;
+  LONG64          minOccurs;
+  LONG64          maxOccurs;
+  LONG64          imin;
+  LONG64          imax;
+  double          rmin;
+  double          rmax;
+  Bool            nillable;
+  int             property;
+  const char      *pattern;
 } Node;
 
 #define ACTION                  0x0000
@@ -331,59 +369,66 @@ typedef struct Node {
 #define PROTOCOL                0x2000
 
 typedef struct Data
-{       struct Data     *next;
-        const char      *name;
-        const char      *text;
+{
+  struct Data     *next;
+  const char      *name;
+  const char      *text;
 } Data;
 
 typedef struct Method
-{       struct Method   *next;
-        const char      *name;
-        short           mess; /* see #defines above */
-        const char      *part;
+{
+  struct Method   *next;
+  const char      *name;
+  short           mess; /* see #defines above */
+  const char      *part;
 } Method;
 
 typedef struct Service
-{       struct Service  *next;
-        const char      *ns;
-        const char      *name;
-        const char      *porttype;
-        const char      *portname;
-        const char      *binding;
-        const char      *definitions;
-        const char      *transport;
-        const char      *URL;
-        const char      *executable;
-        const char      *import;
-        const char      *URI;
-        const char      *URI2;
-        const char      *WSDL;
-        const char      *style;
-        const char      *encoding;
-        const char      *protocol;
-        int             xsi_type;
-        const char      *elementForm;
-        const char      *attributeForm;
-        const char      *documentation;
-        struct Method   *list;
-        struct Data     *data;
+{
+  struct Service  *next;
+  const char      *ns;
+  const char      *name;
+  const char      *porttype;
+  const char      *portname;
+  const char      *binding;
+  const char      *definitions;
+  const char      *transport;
+  const char      *URL;
+  const char      *executable;
+  const char      *import;
+  const char      *URI;
+  const char      *URI2;
+  const char      *WSDL;
+  const char      *style;
+  const char      *encoding;
+  const char      *protocol;
+  int             xsi_type;
+  const char      *elementForm;
+  const char      *attributeForm;
+  const char      *documentation;
+  struct Method   *list;
+  struct Data     *data;
 } Service;
 
 typedef struct XPath
-{       struct XPath    *next;
-        const char      *name;
-        const char      *path;
+{
+  struct XPath    *next;
+  const char      *name;
+  const char      *path;
 } XPath;
 
 typedef struct Pragma
-{       struct Pragma   *next;
-        const char      *pragma;
+{
+  struct Pragma   *next;
+  const char      *pragma;
 } Pragma;
 
 extern Entry *enter(Table*, Symbol*), *entry(Table*, Symbol*), *reenter(Table*, Symbol*), *enumentry(Symbol*);
 
 extern int merge(Table*, Table*);
 
+extern void base_of_derived(Entry*);
+
 extern Table *mktable(Table*);
 
 extern Tnode *mkmethod(Tnode*, Table*);
@@ -427,7 +472,6 @@ extern int iflag;
 extern int jflag;
 extern int mflag;
 extern int nflag;
-extern int nflag;
 extern int lflag;
 extern int Lflag;
 extern int Qflag;
